@@ -198,9 +198,9 @@ impl CircuitWrapper {
     pub fn to_bincode(&self) -> PyResult<Py<PyByteArray>> {
         let serialized = serialize(&self.internal)
             .map_err(|_| PyValueError::new_err("Cannot serialize Circuit to bytes"))?;
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let b: Py<PyByteArray> = PyByteArray::new(py, &serialized[..]).into();
+        let b: Py<PyByteArray> = Python::with_gil(|py| -> Py<PyByteArray> {
+            PyByteArray::new(py, &serialized[..]).into()
+        });
         Ok(b)
     }
 
@@ -349,6 +349,24 @@ impl CircuitWrapper {
         Ok(defs)
     }
 
+    /// Return a list of all operations in the Circuit.
+    ///
+    /// Returns:
+    ///     list[Operation]: A vector of the operations in the Circuit.
+    pub fn operations(&self) -> PyResult<Vec<PyObject>> {
+        let mut ops: Vec<PyObject> = Vec::new();
+        for op in self
+            .internal
+            .operations()
+            .iter()
+            .cloned()
+            .map(convert_operation_to_pyobject)
+        {
+            ops.push(op?)
+        }
+        Ok(ops)
+    }
+
     /// Return a list of operations with given tag.
     ///
     /// Args:
@@ -414,10 +432,10 @@ impl PyObjectProtocol for CircuitWrapper {
     /// Raises:
     ///     NotImplementedError: Other comparison not implemented
     fn __richcmp__(&self, other: Py<PyAny>, op: pyo3::class::basic::CompareOp) -> PyResult<bool> {
-        let gil = pyo3::Python::acquire_gil();
-        let py = gil.python();
-        let other_ref = other.as_ref(py);
-        let other = convert_into_circuit(other_ref);
+        let other = Python::with_gil(|py| -> Result<Circuit, QoqoError> {
+            let other_ref = other.as_ref(py);
+            crate::convert_into_circuit(other_ref)
+        });
         match op {
             pyo3::class::basic::CompareOp::Eq => match other {
                 Ok(circ) => Ok(self.internal == circ),
@@ -444,22 +462,30 @@ impl PyNumberProtocol for CircuitWrapper {
     /// Raises:
     ///     TypeError: Right hand side can not be converted to Operation or Circuit.
     fn __iadd__(&'p mut self, other: Py<PyAny>) -> PyResult<()> {
-        let gil = pyo3::Python::acquire_gil();
-        let py = gil.python();
-        let other_ref = other.as_ref(py);
-        match convert_pyany_to_operation(other_ref) {
-            Ok(x) => self.internal += x,
-            Err(_) => {
-                let other = convert_into_circuit(other_ref).map_err(|x| {
-                    pyo3::exceptions::PyTypeError::new_err(format!(
-                        "Right hand side can not be converted to Operation or Circuit {:?}",
-                        x
-                    ))
-                })?;
-                self.internal += other
+        Python::with_gil(|py| -> PyResult<()> {
+            let other_ref = other.as_ref(py);
+            match convert_pyany_to_operation(other_ref) {
+                Ok(x) => {
+                    self.internal += x;
+                    Ok(())
+                }
+                Err(_) => {
+                    let other = convert_into_circuit(other_ref).map_err(|x| {
+                        pyo3::exceptions::PyTypeError::new_err(format!(
+                            "Right hand side can not be converted to Operation or Circuit {:?}",
+                            x
+                        ))
+                    });
+                    match other {
+                        Ok(x) => {
+                            self.internal += x;
+                            Ok(())
+                        }
+                        Err(y) => Err(y),
+                    }
+                }
             }
-        }
-        Ok(())
+        })
     }
 
     /// Implement the `+` (__add__) magic method to add two Circuits.
@@ -475,27 +501,27 @@ impl PyNumberProtocol for CircuitWrapper {
     ///     TypeError: Left hand side can not be converted to Circuit.
     ///     TypeError: Right hand side can not be converted to Operation or Circuit.
     fn __add__(lhs: Py<PyAny>, rhs: Py<PyAny>) -> PyResult<CircuitWrapper> {
-        let gil = pyo3::Python::acquire_gil();
-        let py = gil.python();
-        let lhs_ref = lhs.as_ref(py);
-        let rhs_ref = rhs.as_ref(py);
-        let self_circ = convert_into_circuit(lhs_ref)
-            .map_err(|_| PyTypeError::new_err("Left hand side can not be converted to Circuit"))?;
-        match convert_pyany_to_operation(rhs_ref) {
-            Ok(x) => Ok(CircuitWrapper {
-                internal: self_circ + x,
-            }),
-            Err(_) => {
-                let other = convert_into_circuit(rhs_ref).map_err(|_| {
-                    pyo3::exceptions::PyTypeError::new_err(
-                        "Right hand side can not be converted to Operation or Circuit",
-                    )
-                })?;
-                Ok(CircuitWrapper {
-                    internal: self_circ + other,
-                })
+        Python::with_gil(|py| -> PyResult<CircuitWrapper> {
+            let (lhs_ref, rhs_ref) = (lhs.as_ref(py), rhs.as_ref(py));
+            let self_circ = convert_into_circuit(lhs_ref).map_err(|_| {
+                PyTypeError::new_err("Left hand side can not be converted to Circuit")
+            })?;
+            match convert_pyany_to_operation(rhs_ref) {
+                Ok(x) => Ok(CircuitWrapper {
+                    internal: self_circ + x,
+                }),
+                Err(_) => {
+                    let other = convert_into_circuit(rhs_ref).map_err(|_| {
+                        pyo3::exceptions::PyTypeError::new_err(
+                            "Right hand side can not be converted to Operation or Circuit",
+                        )
+                    })?;
+                    Ok(CircuitWrapper {
+                        internal: self_circ + other,
+                    })
+                }
             }
-        }
+        })
     }
 }
 
